ResponseError

Struct ResponseError 

pub struct ResponseError { /* private fields */ }
A request to a URI that was expected to return successfully with 200 OK has failed to do so. This contains the status code that was received instead, and the bytes in the body of the response.

Implementations

Source

impl ResponseError

pub fn uri(&self) -> &Url

Reference to the URI of the request.

pub fn bytes(&self) -> &[u8]

Reference to the body bytes of the response.

pub fn into_uri(self) -> Url

Consume this error, taking out the URI of the request.

pub fn into_bytes(self) -> Vec<u8>

Consume this error, taking out the body bytes of the response.

pub fn into_uri_bytes(self) -> (Url, Vec<u8>)

Consume this error, taking out both the URI of the request, and the body bytes of the response.

Source

impl ResponseError

pub fn status_code(&self) -> StatusCode

Copy of the response’s status code.