pub struct ResponseError { /* private fields */ }Expand description
A request to a URI that was expected to return successfully with 200 OK has failed to do so. This contains the status code that was received instead, and the bytes in the body of the response.
Implementations
Sourceimpl ResponseError
impl ResponseError
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consume this error, taking out the body bytes of the response.
Sourcepub fn into_uri_bytes(self) -> (Url, Vec<u8>)
pub fn into_uri_bytes(self) -> (Url, Vec<u8>)
Consume this error, taking out both the URI of the request, and the body bytes of the response.
Sourceimpl ResponseError
impl ResponseError
Sourcepub fn status_code(&self) -> StatusCode
pub fn status_code(&self) -> StatusCode
Copy of the response’s status code.